;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "helm-projectile" "20250902.830"
  "Helm integration for Projectile."
  '((emacs      "26.1")
    (helm       "3.0")
    (projectile "2.9"))
  :url "https://github.com/bbatsov/helm-projectile"
  :commit "0ffb6b5f09c1d65d721c1111ebfa6cec0ba63234"
  :revdesc "0ffb6b5f09c1"
  :keywords '("project" "convenience"))
